//-------------------------------------------
// Options handlers
//-------------------------------------------

/* global jQuery:false */
/* global TRX_EFFECTS_STORAGE:false */

jQuery(document).ready(function() {

	"use strict";

	// Submit form
	jQuery('.trx_effects_options_button_submit').on('click', function() {
		jQuery(this).parents('form').submit();
	});

	// Init fields
	trx_effects_options_init_fields();
	jQuery(document).on('trx_effects_admin_action_init_hidden_elements', trx_effects_options_init_fields);
	
	// Check fields dependencies
	function trx_effects_options_start_check_dependencies() {
		jQuery('.trx_effects_options .trx_effects_options_section').each( function () {
			trx_effects_options_check_dependencies(jQuery(this));
		});
	}
	// Check all inner dependencies
	jQuery( document ).ready( trx_effects_options_start_check_dependencies );
	// Check external dependencies (for example, "Page template" in the page edit mode)
	jQuery( window ).load( trx_effects_options_start_check_dependencies );
	// Check dependencies on any field change
	jQuery('.trx_effects_options .trx_effects_options_item_field [name^="trx_effects_options_field_"]').on('change', function () {
		trx_effects_options_check_dependencies(jQuery(this).parents('.trx_effects_options_section'));
	});
	
	if (typeof TRX_EFFECTS_STORAGE == 'undefined') window.TRX_EFFECTS_STORAGE = {};

	// Prepare media selector params
	TRX_EFFECTS_STORAGE['media_id'] = '';
	TRX_EFFECTS_STORAGE['media_frame'] = [];
	TRX_EFFECTS_STORAGE['media_link'] = [];
	
	// Init fields at first run and after clone group
	function trx_effects_options_init_fields(e, container) {
		
		if (container === undefined) container = jQuery('.trx_effects_options').eq(0);
	
		// Init jQuery Tabs
		if (jQuery.ui && jQuery.ui.tabs) {
			container.find('.trx_effects_tabs:not(.inited)').addClass('inited').tabs({
				create: function( event, ui ) {
					if (ui.panel.length > 0) jQuery(document).trigger('trx_effects_admin_action_init_hidden_elements', [ui.panel]);
				},
				activate: function( event, ui ) {
					if (ui.newPanel.length > 0) jQuery(document).trigger('trx_effects_admin_action_init_hidden_elements', [ui.newPanel]);
				}
			});
			// Check hash and open tab
			var hash  = window.location.hash;
			if (hash && jQuery('a[href="'+hash+'"]').length > 0) {
				setTimeout(function() {
					jQuery('a[href="'+hash+'"]').trigger('click');
				}, 10);
			}
		}
		
		// Init jQuery Accordion
		if (jQuery.ui && jQuery.ui.accordion) {
			container.find('.trx_effects_panels:not(.inited)').addClass('inited').accordion({
				'header': '.trx_effects_panel_title',
				'heightStyle': 'content',
				create: function( event, ui ) {
					if (ui.panel.length > 0) jQuery(document).trigger('trx_effects_admin_action_init_hidden_elements', [ui.panel]);
				},
				activate: function( event, ui ) {
					if (ui.newPanel.length > 0) jQuery(document).trigger('trx_effects_admin_action_init_hidden_elements', [ui.newPanel]);
				}
			});
		}

		// Standard WP Color Picker
		if (container.find('.trx_effects_color_selector:not(.inited)').length > 0) {
			container.find('.trx_effects_color_selector:not(.inited)').addClass('inited').wpColorPicker({
				// you can declare a default color here,
				// or in the data-default-color attribute on the input
				//defaultColor: false,
		
				// a callback to fire whenever the color changes to a valid color
				change: function(e, ui){
					jQuery(e.target).val(ui.color).trigger('change');
				},
		
				// a callback to fire when the input is emptied or an invalid color
				clear: function(e) {
					jQuery(e.target).prev().trigger('change');
				}
		
				// hide the color picker controls on load
				//hide: true,
		
				// show a group of common colors beneath the square
				// or, supply an array of colors to customize further
				//palettes: true
			});
		}
		
		// Icon selector
		// Attention! Init container, because icon_selector appear in a cloneable blocks
		if (!container.hasClass('trx_effects_icon_selector_inited')) {
			container.addClass('trx_effects_icon_selector_inited')
				.on('click', '.trx_effects_icon_selector', function(e) {
					var selector = jQuery(this);
					var list = selector.next('.trx_effects_list_icons');
					if (list.length > 0) {
						if (list.css('display') == 'block') {
							list.slideUp();
						} else {
							var css_obj = {};
							if (selector.parents('#trx_effects_meta_box').length > 0) {
								css_obj = { 
									'position': 'relative',
									'left': 'auto',
									'top': 'auto'
								};
							} else {
								var pos = selector.position();
								css_obj = {
									'position': 'absolute',
									'left': pos.left,
									'top': pos.top+selector.height()+4
								};
							}
							list.find('.trx_effects_list_icons_search').val('');
							list.find('span').removeClass('trx_effects_list_hidden');
							list.css(css_obj).slideDown(function() {
																	list.find('.trx_effects_list_icons_search').focus();
																});
						}
					}
					e.preventDefault();
					return false;
				})
				.on('keyup', '.trx_effects_list_icons_search', function(e) {
					var list = jQuery(this).parent(),
						val = jQuery(this).val();
					list.find('span').removeClass('trx_effects_list_hidden');
					if (val !== '') list.find('span:not([data-icon*="'+val+'"])').addClass('trx_effects_list_hidden');
				})
				.on('click', '.trx_effects_list_icons > span', function(e) {
					var list = jQuery(this).parent();
					list.find('.trx_effects_active').removeClass('trx_effects_active');
					var selector = list.prev('.trx_effects_icon_selector');
					var input = selector.length==1 ? selector.prev('input') : list.prev('input');
					var icon = jQuery(this).addClass('trx_effects_active').data('icon');
					input.val(icon).trigger('change');
					if (selector.length > 0) {
						if (selector.data('style') == 'icons')
							selector.attr('class', trx_effects_chg_icon_class(selector.attr('class'), icon));
						else
							selector.css('background-image', jQuery(this).css('background-image'));
						list.fadeOut();
					}
					e.preventDefault();
					return false;
				});
		}
		
		// Media selector
		container.find('#customize-theme-controls:not(.inited)'
						+',.widget-liquid-right:not(.inited)'
						+',.widgets-holder-wrap:not(.inited)'
						+',.widget_field_type_image:not(.inited)'
						+',.form-field:not(.inited)'
						+',.trx_effects_options_item_field:not(.inited)').addClass('inited')
			.on('click', '.trx_effects_media_selector', function(e) {
				trx_effects_show_media_manager(this);
				e.preventDefault();
				return false;
			})
			.on('click', '.trx_effects_media_selector_preview > span', function(e) {
				var image = jQuery(this);
				var button = image.parent().prev('.trx_effects_media_selector');
				var field = jQuery('#'+button.data('linked-field'));
				if (field.length == 0) return false;
				if (button.data('multiple')==1) {
					var val = field.val().split('|');
					val.splice(image.index(), 1);
					field.val(val.join('|'));
					image.remove();
				} else {
					field.val('');
					image.remove();
				}
				e.preventDefault();
				return false;
			});
		
		// Init checklist
		container.find('.trx_effects_options_item_choises:not(.inited)').addClass('inited')
			.on('change', 'input[type="checkbox"]', function() {
				var choises = '';
				var cont = jQuery(this).parents('.trx_effects_options_item_choises');
				cont.find('input[type="checkbox"]').each(function() {
					choises += (choises ? '|' : '') + jQuery(this).data('name') + '=' + (jQuery(this).get(0).checked ? jQuery(this).val() : '0');
				});
				cont.find('input[type="hidden"]').eq(0).val(choises).trigger('change');
			})
			.each(function() {
				if (jQuery.ui.sortable && jQuery(this).hasClass('trx_effects_options_sortable')) {
					var id = jQuery(this).attr('id');
					if (id === undefined)
						jQuery(this).attr('id', 'trx_effects_options_sortable_'+(''+Math.random()).replace('.', ''));
					jQuery(this).sortable({
						items: ".trx_effects_options_item_sortable",
						placeholder: ' trx_effects_options_item_label trx_effects_options_sortable_placeholder',
						update: function(event, ui) {
							var choises = '';
							ui.item.parent().find('input[type="checkbox"]').each(function() {
								choises += (choises ? '|' : '') 
										+ jQuery(this).data('name') + '=' + (jQuery(this).get(0).checked ? jQuery(this).val() : '0');
							});
							ui.item.siblings('input[type="hidden"]').eq(0).val(choises).trigger('change');
						}
					})
					.disableSelection();
				}
			});


		// Init Select2
		if (jQuery.fn && jQuery.fn.select2) {
			container.find('.trx_effects_options_item_select2 select:not(.inited)').addClass('inited').select2();
		}
	
		// Init datepicker
		if (jQuery.ui.datepicker) {
			container.find('.trx_effects_options_item_date input[type="text"]:not(.inited)').addClass('inited')
				.each(function () {
					var curDate = jQuery(this).val();
					jQuery(this).datepicker({
						dateFormat: jQuery(this).data('format'),
						numberOfMonths: jQuery(this).data('months'),
						gotoCurrent: true,
						changeMonth: true,
						changeYear: true,
						defaultDate: curDate,
						onSelect: function (text, ui) {
							ui.input.trigger('change');
						}
					});
				});
		}

		// Init range slider
		if (jQuery.ui && jQuery.ui.slider) {
			container.find('.trx_effects_range_slider:not(.inited)').each(function () {
				// Get parameters
				var range_slider = jQuery(this);
				var linked_field = range_slider.data('linked_field');
				if (linked_field===undefined)
					linked_field = range_slider.prev('input[type="hidden"],input[type="text"]');
				else
					linked_field = jQuery('#'+linked_field);
				if (linked_field.length == 0) return;
				linked_field.on(
					'change', function() {
						var minimum = range_slider.data( 'min' );
						if (minimum === undefined) {
							minimum = 0;
						}
						var maximum = range_slider.data( 'max' );
						if (maximum === undefined) {
							maximum = 0;
						}
						var values = jQuery( this ).val().split( ',' );
						for (var i = 0; i < values.length; i++) {
							if (isNaN( values[i] )) {
								value[i] = minimum;
							}
							values[i] = Math.max( minimum, Math.min( maximum, Number( values[i] ) ) );
							if (values.length == 1) {
								range_slider.slider( 'value', values );
							} else {
								range_slider.slider( 'values', i, values[i] );
							}
						}
						update_cur_values( values );
						jQuery( this ).val( values.join( ',' ) );
					}
				);
				var range_slider_cur = range_slider.find('> .trx_effects_range_slider_label_cur');
				var range_slider_type = range_slider.data('range');
				if (range_slider_type===undefined) range_slider_type = 'min';
				var values = linked_field.val().split(',');
				var minimum = range_slider.data('min');
				if (minimum===undefined) minimum = 0;
				var maximum = range_slider.data('max');
				if (maximum===undefined) maximum = 0;
				var step = range_slider.data('step');
				if (step===undefined) step = 1;
				// Init range slider
				var init_obj = {
					range: range_slider_type,
					min: minimum,
					max: maximum,
					step: step,
					slide: function(event, ui) {
						var cur_values = range_slider_type === 'min' ? [ui.value] : ui.values;
						linked_field.val(cur_values.join(',')).trigger('change');
						update_cur_values( cur_values );
					},
					create: function(event, ui) {
						update_cur_values( values );
					}
				};
				function update_cur_values(cur_values) {
					for (var i = 0; i < cur_values.length; i++) {
						range_slider_cur.eq( i )
							.html( cur_values[i] )
							.css( 'left', Math.max( 0, Math.min( 100, (cur_values[i] - minimum) * 100 / (maximum - minimum) ) ) + '%' );
					}
				}
				if (range_slider_type === true)
					init_obj.values = values;
				else
					init_obj.value = values[0];
				range_slider.addClass('inited').slider(init_obj);
			});
		}
	
		// Init masked input
		container.find('.trx_effects_options_item input[data-mask]:not(.inited)').addClass('inited')
			.each(function () {
				if (jQuery.fn && jQuery.fn.mask) jQuery(this).mask(''+jQuery(this).data('mask'));
			});


		// Button with action
		container.find('.trx_effects_options_item_button input[type="button"]:not(.inited)').addClass('inited')
			.on('click', function(e) {
				var button = jQuery(this),
					cb = button.data('callback');
				if (cb !== undefined && typeof window[cb] !== 'undefined') {
					window[cb]( button );
				} else {
					jQuery.post(TRX_EFFECTS_STORAGE['ajax_url'], {
						action: button.data('action'),
						nonce: TRX_EFFECTS_STORAGE['ajax_nonce']
					}).done(function(response) {
						var rez = {};
						if (response === '' || response === 0) {
							rez = { error: TRX_EFFECTS_STORAGE['msg_ajax_error'] };
						} else {
							try {
								rez = JSON.parse(response);
							} catch (e) {
								rez = { error: TRX_EFFECTS_STORAGE['msg_ajax_error'] };
								console.log(response);
							}
						}
						if ( rez.error || rez.success.substring(0,2) != 'a:' ) {
							alert(rez.error ? rez.error : rez.success);
							console.log(rez.error ? rez.error : rez.success);
						} else {
							var data = button.parents( '.trx_effects_options_item_data' ),
								msg  = data.find( '> .trx_effects_options_item_msg' );
							if ( msg.length === 0 ) {
								data.append( '<div class="trx_effects_options_item_msg"></div>' );
								msg = data.find( '> .trx_effects_options_item_msg' );
							}
							msg.html(rez.success);
						}
					});
				}
				e.preventDefault();
				return false;
			});


		// Show WP Media manager to select image
		// -------------------------------------------------------------------------------------
		function trx_effects_show_media_manager(el) {
		
			TRX_EFFECTS_STORAGE['media_id'] = jQuery(el).attr('id');
			TRX_EFFECTS_STORAGE['media_link'][TRX_EFFECTS_STORAGE['media_id']] = jQuery(el);
			// If the media frame already exists, reopen it.
			if ( TRX_EFFECTS_STORAGE['media_frame'][TRX_EFFECTS_STORAGE['media_id']] ) {
				TRX_EFFECTS_STORAGE['media_frame'][TRX_EFFECTS_STORAGE['media_id']].open();
				return false;
			}
		
			// Create the media frame
			var type = TRX_EFFECTS_STORAGE['media_link'][TRX_EFFECTS_STORAGE['media_id']].data('type') 
							? TRX_EFFECTS_STORAGE['media_link'][TRX_EFFECTS_STORAGE['media_id']].data('type') 
							: 'image';
			var args = {
				// Set the title of the modal.
				title: TRX_EFFECTS_STORAGE['media_link'][TRX_EFFECTS_STORAGE['media_id']].data('choose'),
				// Multiple choise
				multiple: TRX_EFFECTS_STORAGE['media_link'][TRX_EFFECTS_STORAGE['media_id']].data('multiple')==1 
							? 'add' 
							: false,
				// Customize the submit button.
				button: {
					// Set the text of the button.
					text: TRX_EFFECTS_STORAGE['media_link'][TRX_EFFECTS_STORAGE['media_id']].data('update'),
					// Tell the button not to close the modal, since we're
					// going to refresh the page when the image is selected.
					close: true
				}
			};
			// Allow sizes and filters for the images
			if (type == 'image') {
				args['frame'] = 'post';
			}
			// Tell the modal to show only selected post types
			if (type == 'image' || type == 'audio' || type == 'video') {
				args['library'] = {
					type: type
				};
			}
			TRX_EFFECTS_STORAGE['media_frame'][TRX_EFFECTS_STORAGE['media_id']] = wp.media(args);
		
			// When an image is selected, run a callback.
			TRX_EFFECTS_STORAGE['media_frame'][TRX_EFFECTS_STORAGE['media_id']].on( 'insert select', function(selection) {
				// Grab the selected attachment.
				var field = jQuery("#"+TRX_EFFECTS_STORAGE['media_link'][TRX_EFFECTS_STORAGE['media_id']].data('linked-field')).eq(0);
				var attachment = null, attachment_url = '';
				if (TRX_EFFECTS_STORAGE['media_link'][TRX_EFFECTS_STORAGE['media_id']].data('multiple')==1) {
					TRX_EFFECTS_STORAGE['media_frame'][TRX_EFFECTS_STORAGE['media_id']].state().get('selection').map( function( att ) {
						attachment_url += (attachment_url ? "|" : "") + att.toJSON().url;
					});
					var val = field.val();
					attachment_url = val + (val ? "|" : '') + attachment_url;
				} else {
					attachment = TRX_EFFECTS_STORAGE['media_frame'][TRX_EFFECTS_STORAGE['media_id']].state().get('selection').first().toJSON();
					attachment_url = attachment.url;
					var sizes_selector = jQuery('.media-modal-content .attachment-display-settings select.size');
					if (sizes_selector.length > 0) {
						var size = trx_effects_get_listbox_selected_value(sizes_selector.get(0));
						if (size !== '') attachment_url = attachment.sizes[size].url;
					}
				}
				// Display images in the preview area
				var preview = field.siblings('.trx_effects_media_selector_preview');
				if (preview.length == 0) {
					jQuery('<span class="trx_effects_media_selector_preview"></span>').insertAfter(field);
					preview = field.siblings('.trx_effects_media_selector_preview');
				}
				if (preview.length != 0) preview.empty();
				var images = attachment_url.split("|");
				for (var i=0; i < images.length; i++) {
					if (preview.length != 0) {
						var ext = trx_effects_get_file_ext(images[i]);
						preview.append('<span>'
										+ (ext=='gif' || ext=='jpg' || ext=='jpeg' || ext=='png' 
												? '<img src="'+images[i]+'">'
												: '<a href="'+images[i]+'">'+trx_effects_get_file_name(images[i])+'</a>'
											)
										+ '</span>');
					}
				}
				// Update field
				field.val(attachment_url).trigger('change');
			});
		
			// Finally, open the modal.
			TRX_EFFECTS_STORAGE['media_frame'][TRX_EFFECTS_STORAGE['media_id']].open();
			return false;
		}
	
		
		// CLONE GROUP OF FIELDS
		//--------------------------------------------------

		// Init cloned fields
		trx_effects_options_clone_toggle_buttons(container);
		container.find('.trx_effects_options_group:not(.inited)').addClass('inited').each(function() {
			jQuery(this)
				// Button 'Clone'
				.on('click', '.trx_effects_options_clone > .trx_effects_options_clone_control_add', function (e) {
					var clone_obj = jQuery(this).parents('.trx_effects_options_clone'),
						group = clone_obj.parents('.trx_effects_options_group');
					// Clone fields
					trx_effects_options_clone(clone_obj);
					// Enable/Disable clone buttons
					trx_effects_options_clone_toggle_buttons(group);
					// Prevent bubble event
					e.preventDefault();
					return false;
				})
				// Button 'Delete'
				.on('click', '.trx_effects_options_clone > .trx_effects_options_clone_control_delete', function (e) {
					var clone_obj = jQuery(this).parents('.trx_effects_options_clone'),
						clone_idx = clone_obj.prev('.trx_effects_options_clone').length,
						group = clone_obj.parents('.trx_effects_options_group');
					// Delete clone
					clone_obj.remove();
					// Change fields index
					trx_effects_options_clone_change_index(group, clone_idx);
					// Enable/Disable clone buttons
					trx_effects_options_clone_toggle_buttons(group);
					// Prevent bubble event
					e.preventDefault();
					return false;
				});
			// Sort clones
			if (jQuery.ui.sortable) {
				var id = jQuery(this).attr('id');
				if (id === undefined) {
					jQuery(this).attr('id', 'trx_effects_options_sortable_'+(''+Math.random()).replace('.', ''));
				}
				jQuery(this)
					.sortable({
						items: '.trx_effects_options_clone',
						handle: '.trx_effects_options_clone_control_move',
						placeholder: ' trx_effects_options_clone trx_effects_options_clone_placeholder',
						start: function (event, ui) {
							// Make the placeholder has the same height as dragged item
							ui.placeholder.height(ui.item.height());
						},
						update: function(event, ui) {
							// Change fields index
							trx_effects_options_clone_change_index(ui.item.parents('.trx_effects_options_group'), 0);
						}
					});
			}
		});
		
		// Check clone controls for enable/disable
		function trx_effects_options_clone_toggle_buttons(container) {
			if (!container.hasClass('trx_effects_options_group'))
				container = container.find('.trx_effects_options_group');
			container.each(function() {
				var group = jQuery(this);
				if (group.find('.trx_effects_options_clone').length > 1)
					group.find('.trx_effects_options_clone_control_delete,.trx_effects_options_clone_control_move').show();
				else
					group.find('.trx_effects_options_clone_control_delete,.trx_effects_options_clone_control_move').hide();
			});
		}
		
		// Replace number in the param's name like 'floor_plans[0][image]'
		function trx_effects_options_clone_replace_index(name, idx_new) {
			name = name.replace(/\[\d{1,2}\]/, '['+idx_new+']');
			return name;
		}
		
		// Change index in each field in the clone
		function trx_effects_options_clone_change_index(group, from_idx) {
			group.find('.trx_effects_options_clone').each(function(idx) {
				if (idx < from_idx) return;
				jQuery(this).find('.trx_effects_options_item_field').each(function() {
					var field = jQuery(this);
					field.attr('data-param', trx_effects_options_clone_replace_index(field.data('param'), idx));
					field.find(':input').each(function() {
						var input = jQuery(this),
							id = input.attr('id'),
							name = input.attr('name');
						if (!name) return;
						name = trx_effects_options_clone_replace_index(name, idx);
						input.attr('name', name);
						if (id) {
							var id_new = name.replace(/\[/g, '_').replace(/\]/g, '');
							input.attr('id', id_new);
							var linked_field = field.find('[data-linked-field="'+id+'"]');
							if (linked_field.length > 0) {
								linked_field.attr('data-linked-field', id_new);
								if (linked_field.attr('id')) {
									linked_field.attr('id', linked_field.attr('id').replace(id, id_new));
								}
							}
						}
					});
				});
			});
		}
		
		// Clone set of the fields
		function trx_effects_options_clone(obj) {
			var group = obj.parent(),
				clone = obj.clone(),
				inputs = clone.find('.trx_effects_options_item_field :input'),
				obj_idx = obj.prev('.trx_effects_options_clone').length;
			// Remove class 'inited' from all elements
			clone.find('.inited').removeClass('inited');
			// Reset value for fields
			inputs.each(function() {
				var input = jQuery(this);
				if (input.is(':radio') || input.is(':checkbox')) {
					input.prop('checked', false);
				} else if (input.is('select')) {
					input.prop('selectedIndex', -1);
				} else if (!input.is(':button')) {
					input.val('');
				}
				// Remove image preview
				input.parents('.trx_effects_options_item_field').find('.trx_effects_media_selector_preview').empty();
				// Remove class 'inited' from selectors
				input.next('[class*="_selector"].inited').removeClass('inited');
			});
			//Remove UI sliders
			clone.find('.ui-slider-range, .ui-slider-handle').remove();
			// Insert Clone
			clone.insertAfter(obj);
			// Change fields index. Must run before trigger clone event
			trx_effects_options_clone_change_index(group, obj_idx);
			// Fire init actions for cloned fields
			jQuery(document).trigger('trx_effects_admin_action_init_hidden_elements', [clone.parents('.trx_effects_options')]);
		}
	}


	// DEPENDENCIES
	//--------------------------------------------------
	
	// Check for dependencies
	function trx_effects_options_check_dependencies(cont) {
		if (typeof TRX_EFFECTS_DEPENDENCIES == 'undefined') return;
		cont.find('.trx_effects_options_item_field,.trx_effects_options_group[data-param]').each(function() {
			var ctrl = jQuery(this), id = ctrl.data('param');
			if (id == undefined) return;
			var depend = false;
			for (var fld in TRX_EFFECTS_DEPENDENCIES) {
				if (fld == id) {
					depend = TRX_EFFECTS_DEPENDENCIES[id];
					break;
				}
			}
			if (depend) {
				var dep_cnt = 0, dep_all = 0;
				var dep_cmp = typeof depend.compare != 'undefined' ? depend.compare.toLowerCase() : 'and';
				var dep_strict = typeof depend.strict != 'undefined';
				var fld=null, val='', name='', subname='', i;
				var parts = '', parts2 = '';
				for (i in depend) {
					if (i == 'compare' || i == 'strict') continue;
					dep_all++;
					name = i;
					subname = '';
					if (name.indexOf('[') > 0) {
						parts = name.split('[');
						name = parts[0];
						subname = parts[1].replace(']', '');
					}
					if (name.charAt(0)=='#') {
						fld = jQuery(name);
						if (fld.length > 0 && !fld.hasClass('trx_effects_inited')) {
							fld.addClass('trx_effects_inited').on('change', function () {
								jQuery('.trx_effects_options .trx_effects_options_section').each(function () {
									trx_effects_options_check_dependencies(jQuery(this));
								});
							});
						}
					} else
						fld = cont.find('[name="trx_effects_options_field_'+name+'"]');
					if (fld.length > 0) {
						val = trx_effects_options_get_field_value(fld);
						if (subname !== '') {
							parts = val.split('|');
							for (var p=0; p < parts.length; p++) {
								parts2 = parts[p].split('=');
								if (parts2[0]==subname) {
									val = parts2[1];
								}
							}
						}
						for (var j in depend[i]) {
							if ( 
								   (depend[i][j]=='not_empty' && val !== '')	// Main field value is not empty - show current field
								|| (depend[i][j]=='is_empty' && val === '')		// Main field value is empty - show current field
								|| (val !== '' && (!isNaN(depend[i][j]) 		// Main field value equal to specified value - show current field
													? val==depend[i][j]
													: (dep_strict 
															? val==depend[i][j]
															: (''+val).indexOf(depend[i][j])==0
														)
												)
									)
								|| (val !== '' && (""+depend[i][j]).charAt(0) == '^' && (''+val).indexOf(depend[i][j].substr(1))==-1)
																			// Main field value not equal to specified value - show current field
							) {
								dep_cnt++;
								break;
							}
						}
					}
					if (dep_cnt > 0 && dep_cmp == 'or')
						break;
				}
				if ( !ctrl.hasClass('trx_effects_options_group') ) {
					ctrl = ctrl.parents('.trx_effects_options_item');
				}
				if ((dep_cnt > 0 && dep_cmp == 'or') || (dep_cnt == dep_all && dep_cmp == 'and')) {
					ctrl.show().removeClass('trx_effects_options_no_use');
				} else {
					ctrl.hide().addClass('trx_effects_options_no_use');
				}
			}
		});
	}

	// Return value of the field
	function trx_effects_options_get_field_value(fld) {
		var ctrl = fld.parents('.trx_effects_options_item_field');
		var val = fld.attr('type')=='checkbox' || fld.attr('type')=='radio' 
					? (ctrl.find('[name^="trx_effects_options_field_"]:checked').length > 0
						? (ctrl.find('[name^="trx_effects_options_field_"]:checked').val() !== ''
							&& ''+ctrl.find('[name^="trx_effects_options_field_"]:checked').val() !== '0'
								? ctrl.find('[name^="trx_effects_options_field_"]:checked').val()
								: 1
							)
						: 0
						)
					: fld.val();
		if (val===undefined || val===null) val = '';
		return val;
	}


	// Import options callback (allow global access)
	window.trx_effects_import_options_callback = function( button ) {
		var options = prompt( TRX_EFFECTS_STORAGE['msg_prompt_options'], '' );
		if ( options ) {
			jQuery.post(TRX_EFFECTS_STORAGE['ajax_url'], {
				action: button.data('action'),
				options: options,
				nonce: TRX_EFFECTS_STORAGE['ajax_nonce']
			}).done(function(response) {
				var rez = {};
				if (response === '' || response === 0) {
					rez = { error: TRX_EFFECTS_STORAGE['msg_ajax_error'] };
				} else {
					try {
						rez = JSON.parse(response);
					} catch (e) {
						rez = { error: TRX_EFFECTS_STORAGE['msg_ajax_error'] };
						console.log(response);
					}
				}
				alert(rez.error ? rez.error : rez.success);
				if ( ! rez.error ) {
					history.go(0);
				}
			});
		}
	};

});