<?php
namespace TrxEffects\Core\Modules\ImageMask;

use TrxEffects\Plugin;
use TrxEffects\Core\Modules\Module;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class ImageMaskElementor extends Module {

	/**
	 * Class constructor.
	 *
	 * Initializing module.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {
		add_action( 'trx_effects_action/init', array( $this, 'init' ) );
	}


	/**
	 * Init module
	 *
	 * Do init actions of the module
	 *
	 * @hook action 'trx_effects_action/init'
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function init() {

		// Add module-specific parameters to the params for all Elementor's modules
		add_action( 'elementor/element/before_section_start', array( $this, 'add_params_to_all_elements' ), 10, 3 );
		add_action( 'elementor/widget/before_section_start', array( $this, 'add_params_to_all_elements' ), 10, 3 );
	}


	/**
	 * Image mask parameters for all elements
	 *
	 * Add module-specific parameters to the params for all Elementor's modules
	 *
	 * @hook action 'elementor/element/before_section_start'
	 * @hook action 'elementor/widget/before_section_start'
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function add_params_to_all_elements( $element, $section_id, $args ) {


		if ( ! is_object($element) ) return;

		if ( in_array( $element->get_name(), array( 'section', 'column', 'common' ) ) && $section_id == '_section_responsive' ) {
			
			$element->start_controls_section( 'section_trx_image_mask', array(
																		'tab' => !empty($args['tab']) ? $args['tab'] : \Elementor\Controls_Manager::TAB_ADVANCED,
																		'label' => esc_html__( 'Image mask', 'trx-effects' )
																	) );

			$element->add_control( 'image_mask', array(
				'label' => esc_html__( 'Mask image', 'trx-effects' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => '',
				],
				'selectors' => [
					'{{WRAPPER}}' => '-webkit-mask-image:url({{URL}});mask-image:url({{URL}});',
				],
			) );

			$element->add_control( 'image_mask_size', array(
				'type' => \Elementor\Controls_Manager::SELECT,
				'label' => esc_html__( 'Mask size', 'trx-effects' ),
				'label_block' => false,
				'options' => apply_filters( 'trx_effects_filter/image_mask_sizes', array(
					'contain' => esc_html__( 'Contain', 'trx-effects' ),
					'cover'  => esc_html__( 'Cover', 'trx-effects' ),
					'unset' => esc_html__( 'Normal', 'trx-effects' ),
				) ),
				'condition' => array(
					'image_mask[url]!' => ''
				),
				'default' => 'contain',
				'selectors' => [
					'{{WRAPPER}}' => '-webkit-mask-size:{{VALUE}};mask-size:{{VALUE}};',
				],
			) );

			$element->add_control( 'image_mask_position', array(
				'type' => \Elementor\Controls_Manager::SELECT,
				'label' => esc_html__( 'Mask position', 'trx-effects' ),
				'label_block' => false,
				'options' => apply_filters( 'trx_effects_filter/image_mask_positions', array(
					'top left' => esc_html__( 'Top Left', 'trx-effects' ),
					'top center' => esc_html__( 'Top Center', 'trx-effects' ),
					'top right' => esc_html__( 'Top Right', 'trx-effects' ),
					'center left' => esc_html__( 'Center Left', 'trx-effects' ),
					'center center' => esc_html__( 'Center Center', 'trx-effects' ),
					'center right' => esc_html__( 'Center Right', 'trx-effects' ),
					'bottom left' => esc_html__( 'Bottom Left', 'trx-effects' ),
					'bottom center' => esc_html__( 'Bottom Center', 'trx-effects' ),
					'bottom right' => esc_html__( 'Bottom Right', 'trx-effects' ),
				) ),
				'default' => 'center center',
				'condition' => array(
					'image_mask[url]!' => ''
				),
				'selectors' => [
					'{{WRAPPER}}' => '-webkit-mask-position:{{VALUE}};mask-position:{{VALUE}};',
				],
			) );

			$element->add_control( 'image_mask_repeat', array(
				'type' => \Elementor\Controls_Manager::SELECT,
				'label' => esc_html__( 'Mask repeat', 'trx-effects' ),
				'label_block' => false,
				'options' => apply_filters( 'trx_effects_filter/image_mask_repeats', array(
					'no-repeat' => esc_html__( 'No repeat', 'trx-effects' ),
					'repeat'    => esc_html__( 'Repeat', 'trx-effects' ),
					'repeat-x'  => esc_html__( 'Repeat X', 'trx-effects' ),
					'repeat-y'  => esc_html__( 'Repeat Y', 'trx-effects' ),
				) ),
				'default' => 'no-repeat',
				'condition' => array(
					'image_mask[url]!' => ''
				),
				'selectors' => [
					'{{WRAPPER}}' => '-webkit-mask-repeat:{{VALUE}};mask-repeat:{{VALUE}};',
				],
			) );

			$element->end_controls_section();
		}
	}

}
