<?php
namespace TrxEffects\Core\Modules;

use TrxEffects\Plugin;


if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

abstract class Module {

	/**
	 * Class constructor.
	 *
	 * Initializing module.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {
	}

	/**
	 * Load modules
	 *
	 * Create instance of modules
	 *
	 * @hook action 'trx_effects_action/load'
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function load() {
	}


	/**
	 * Init module
	 *
	 * Do init actions of the module
	 *
	 * @hook action 'trx_effects_action/init'
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function init() {
	}


	/**
	 * Get option.
	 *
	 * Return option value by name ( a shorthand for Plugin->options->get_option() ).
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function get_option( $name, $defa = '', $strict_mode = true ) {
		return Plugin::instance()->options->get_option( $name, $defa, $strict_mode );
	}


	/**
	 * Check if option name exists
	 *
	 * Return true if an option with specified name exists.
	 * ( a shorthand for Plugin->options->check_option() ).
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function check_option( $name ) {
		return Plugin::instance()->options->check_option( $name );
	}


	/**
	 * Add inline CSS to the page.
	 *
	 * Add inline CSS to the footer of the page ( a shorthand for Plugin->html->add_inline_css() ).
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function add_inline_css( $css, $suffix='' ) {
		return Plugin::instance()->html->add_inline_css( $css, $suffix );
	}

}
