<?php
namespace TrxEffects\Core\Modules\MouseHelper;

use TrxEffects\Plugin;
use TrxEffects\Core\Modules\Module;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class MouseHelper extends Module {

	/**
	 * Elementor API object.
	 *
	 * Holds the object with Elementor API.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @var elementor
	 */
	public $elementor;


	/**
	 * Class constructor.
	 *
	 * Initializing module.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {
		add_filter( 'trx_effects_filter/options_list', array( $this, 'options_list' ) );
		add_action( 'trx_effects_action/load', array( $this, 'load' ), 20 );	// Need priority greater then 10 ( each next level of 'load' must be greater then caller class )
		add_action( 'trx_effects_action/init', array( $this, 'init' ) );
	}

	/**
	 * Load modules
	 *
	 * Create instance of modules
	 *
	 * @hook action 'trx_effects_action/load'
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function load() {
		parent::load();
		$this->elementor = new MouseHelperElementor();
	}


	/**
	 * Init module
	 *
	 * Do init actions of the module
	 *
	 * @hook action 'trx_effects_action/init'
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function init() {
		parent::init();
		// Load scripts
		add_action( 'wp_enqueue_scripts', array( $this, 'load_scripts' ) );
		add_filter( 'trx_effects_filter/localize_scripts_front', array( $this, 'localize_scripts_front' ) );
		// Add layout to the page
		add_filter( 'trx_effects_filter/put_inline_html', array( $this, 'add_layout_to_body' ) );
		// Replace system cursor
		add_filter( 'body_class', array( $this, 'replace_system_cursor' ) );
	}


	/**
	 * Options of this module
	 *
	 * Add module-specific options to the global plugin's options
	 *
	 * @hook filter 'trx_effects_filter/options_list'
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function options_list( $options ) {
		return array_merge( $options, array(
			'mouse_helper_section' => array(
				"title" => esc_html__('Mouse Helper', 'trx-effects'),
				"desc" => esc_html__("Settings of the module 'Mouse Helper'", 'trx-effects' ),
				"type" => "section"
			),
			'mouse_helper_info' => array(
				"title" => esc_html__('Mouse Helper', 'trx-effects'),
				"desc" => esc_html__( "Settings of the module 'Mouse Helper'", 'trx-effects' ),
				"type" => "info"
			),
			'mouse_helper_replace_cursor' => array(
				"title" => esc_html__('System cursor', 'trx-effects'),
				"desc" => esc_html__( 'Replace system cursor with custom image', 'trx-effects' ),
				"options" => array(
					"0"    => esc_html__( 'Default', 'trx-effects' ),
					"1"    => esc_html__( 'Replace', 'trx-effects' ),
					"hide" => esc_html__( 'Hide', 'trx-effects' ),
				),
				"std" => "default",
				"type" => "radio"
			),
			'mouse_helper_replace_cursor_default' => array(
				"title" => esc_html__('Default cursor image',  'trx-effects'),
				"desc" => esc_html__('Select or upload image (up to 32x32) to use it as default cursor. If you select animated cursor .ANI - select alternative cursor for not supported browsers in the next field', 'trx-effects'),
				//"class" => "trx_effects_column-1_2",
				"dependency" => array(
					'mouse_helper_replace_cursor' => array( 1 )
				),
				"std" => "",
				"type" => "image"
			),
			'mouse_helper_replace_cursor_default2' => array(
				"title" => esc_html__('Default cursor image (alternative)',  'trx-effects'),
				"desc" => esc_html__('Select or upload image (up to 32x32) to use it as alternative cursor.', 'trx-effects'),
				//"class" => "trx_effects_column-1_2",
				"dependency" => array(
					'mouse_helper_replace_cursor' => array( 1 ),
					'mouse_helper_replace_cursor_default' => array( 'not_empty' )
				),
				"std" => "",
				"type" => "image"
			),
			'mouse_helper_replace_cursor_links' => array(
				"title" => esc_html__('Cursor image over links',  'trx-effects'),
				"desc" => esc_html__('Select or upload image (up to 32x32) to use it as cursor over links and buttons.  If you select animated cursor .ANI - select alternative cursor for not supported browsers in the next field', 'trx-effects'),
				//"class" => "trx_effects_column-1_2",
				"dependency" => array(
					'mouse_helper_replace_cursor' => array( 1 )
				),
				"std" => "",
				"type" => "image"
			),
			'mouse_helper_replace_cursor_links2' => array(
				"title" => esc_html__('Cursor image over links (alternative)',  'trx-effects'),
				"desc" => esc_html__('Select or upload image (up to 32x32) to use it as alternative cursor.', 'trx-effects'),
				//"class" => "trx_effects_column-1_2",
				"dependency" => array(
					'mouse_helper_replace_cursor' => array( 1 ),
					'mouse_helper_replace_cursor_links' => array( 'not_empty' )
				),
				"std" => "",
				"type" => "image"
			),
			'mouse_helper' => array(
				"title" => esc_html__('Show mouse helper', 'trx-effects'),
				"desc" => esc_html__('Display animated helper near the mouse cursor on desktop and notebooks', 'trx-effects'),
				"std" => "0",
				"type" => "switch"
			),
			'mouse_helper_permanent' => array(
				"title" => esc_html__('Always visible', 'trx-effects'),
				"desc" => esc_html__('Display the mouse helper permanently or only when hovering over the corresponding object', 'trx-effects'),
				"dependency" => array(
					'mouse_helper' => array( 1 )
				),
				"std" => 0,
				"type" => "switch"
			),
			'mouse_helper_centered' => array(
				"title" => esc_html__('Centered', 'trx-effects'),
				"desc" => esc_html__('Place the center of the helper in the cursor position', 'trx-effects'),
				"dependency" => array(
					'mouse_helper' => array( 1 )
				),
				"std" => 0,
				"type" => "switch"
			),
			'mouse_helper_bg_color' => array(
				"title" => esc_html__('Background color', 'trx-effects'),
				"desc" => esc_html__('Background color of the helper', 'trx-effects'),
				"dependency" => array(
					'mouse_helper' => array( 1 )
				),
				"std" => '#6ec1e4',
				"type" => "color"
			),
			'mouse_helper_bd_color' => array(
				"title" => esc_html__('Border color', 'trx-effects'),
				"desc" => esc_html__('Border color of the helper', 'trx-effects'),
				"dependency" => array(
					'mouse_helper' => array( 1 )
				),
				"std" => '',
				"type" => "color"
			),
			'mouse_helper_color' => array(
				"title" => esc_html__('Text color', 'trx-effects'),
				"desc" => esc_html__('Color of the inner text', 'trx-effects'),
				"dependency" => array(
					'mouse_helper' => array( 1 )
				),
				"std" => '#fff',
				"type" => "color"
			),
			'mouse_helper_delay' => array(
				"title" => esc_html__('Delay', 'trx-effects'),
				"desc" => esc_html__('The coefficient of lag between the helper and the cursor (1 - the helper moves with the cursor)', 'trx-effects'),
				"dependency" => array(
					'mouse_helper' => array( 1 )
				),
				"std" => 10,
				"min" => 1,
				"max" => 20,
				"type" => "slider"
			),
		) );
	}


	/**
	 * Load scripts and styles
	 *
	 * Enqueue module-specific scripts and styles
	 *
	 * @hook action 'wp_enqueue_scripts'
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function load_scripts() {
		wp_enqueue_style(  'trx-effects-mouse-helper', Plugin::instance()->files->get_file_url( TRX_EFFECTS_MODULES . 'mouse-helper/mouse-helper.css' ), array(), null );
		wp_enqueue_script( 'trx-effects-mouse-helper', Plugin::instance()->files->get_file_url( TRX_EFFECTS_MODULES . 'mouse-helper/mouse-helper.js' ), array('jquery'), null, true );
	}


	/**
	 * Localize frontend scripts.
	 *
	 * Add module-specific vars to the general array.
	 *
	 * @hook action 'trx_effects_filter/localize_script'
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function localize_scripts_front( $vars ) {
		$vars['mouse_helper']            = (int) $this->get_option( 'mouse_helper' );
		$vars['mouse_helper_delay']      = max( 1, min( 20, (int) $this->get_option('mouse_helper_delay') ) );
		$vars['mouse_helper_centered']   = (int) $this->get_option( 'mouse_helper_centered' );
		$vars['msg_mouse_helper_anchor'] = (int) $this->get_option( 'mouse_helper' ) > 0 ? esc_attr__( 'Scroll to', 'trx-effects' ) : '';
		$vars['mobile_breakpoint_mousehelper_off'] = 1025;
		return $vars;
	}


	/**
	 * Add mouse helper layout to the page.
	 *
	 * Append html layout of the mouse helper to the 'body' of current page
	 *
	 * @hook filter 'trx_effects_filter/put_inline_html'
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function add_layout_to_body( $html ) {
		if ( (int) $this->get_option( 'mouse_helper' ) > 0 ) {
			ob_start();
			?><div class="<?php
				echo esc_attr( apply_filters( 'trx_effects_filter/mouse_helper_classes',
												'trx_effects_mouse_helper'
												. ( (int) $this->get_option( 'mouse_helper_permanent' ) > 0
														? ' trx_effects_mouse_helper_permanent'
														: ''
														)
												. ( (int) $this->get_option( 'mouse_helper_centered' ) > 0
														? ' trx_effects_mouse_helper_centered'
														: ''
														)
											)
							);
				?>" style="<?php
					if ( $this->get_option( 'mouse_helper_color' ) != '' )    echo 'color:' . esc_attr( $this->get_option( 'mouse_helper_color' ) ) . ';';
					if ( $this->get_option( 'mouse_helper_bg_color' ) != '' ) echo 'background-color:' . esc_attr( $this->get_option( 'mouse_helper_bg_color' ) ) . ';';
					if ( $this->get_option( 'mouse_helper_bd_color' ) != '' ) echo 'border-color:' . esc_attr( $this->get_option( 'mouse_helper_bd_color' ) ) . ';';
				?>"
				<?php
				do_action( 'trx_effects_action/mouse_helper_attributes' );
			?>><?php
				do_action( 'trx_effects_action/mouse_helper_layout' );
			?></div><?php
			$html .= ob_get_contents();
			ob_end_clean();
		}
		return $html;
	}


	/**
	 * Replace system cursor.
	 *
	 * Add class to 'body' to replace system cursor with a custom image, specified in the plugin's options
	 *
	 * @hook action 'body_class'
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function replace_system_cursor( $classes ) {
		if ( (int) $this->get_option( 'mouse_helper_replace_cursor' ) == 1 ) {
			$classes[]  = 'trx_effects_mouse_helper_custom_cursor';
			$cur_defa   = $this->get_option( 'mouse_helper_replace_cursor_default' );
			$cur_defa2  = $this->get_option( 'mouse_helper_replace_cursor_default2' );
			$cur_links  = $this->get_option( 'mouse_helper_replace_cursor_links' );
			$cur_links2 = $this->get_option( 'mouse_helper_replace_cursor_links2' );
			if ( ! empty( $cur_defa ) ) {
				$this->add_inline_css(
					join( ',', apply_filters( 'trx_effects_filter/mouse_helper_custom_cursor_default', array(
						'body',
						'body *'
					) ) )
					. ' { cursor: '
						. 'url(' . esc_url( $cur_defa ) . ')'
						. ( ! empty( $cur_defa2 ) ? ',url(' . esc_url( $cur_defa2 ) . ')' : '' )
						. ', auto !important; }'
					);
			}
			if ( ! empty( $cur_links ) ) {
				$this->add_inline_css(
					join( ',', apply_filters( 'trx_effects_filter/mouse_helper_custom_cursor_links', array(
						'body a',
						'body a *',
						'body button',
						'body input[type="submit"]',
						'body input[type="button"]',
						'body input[type="reset"]'
					) ) )
					. ' { cursor: '
						. 'url(' . esc_url( $cur_links ) . ')'
						. ( ! empty( $cur_links2 ) ? ',url(' . esc_url( $cur_links2 ) . ')' : '' )
						. ', pointer !important; }'
					);
			}
		} else if ( in_array( $this->get_option( 'mouse_helper_replace_cursor' ), array( '2', 'hide' ) ) ) {
			if ( ! Plugin::instance()->elementor->is_preview() ) {
				$classes[]  = 'trx_effects_mouse_helper_hide_cursor';
			}
		}
		return $classes;
	}

}
