<?php
namespace TrxEffects\Core\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * An option field of the type 'button'
 *
 * Add a button to the options page
 *
 * @since 1.0.0
 */
class CustomizerFieldButton extends CustomizerField {

	/**
	 * Display an inner layout of the field.
	 *
	 * Display tags inside field's wrapper.
	 *
	 * @param (string) name - a name of the field
	 * @param (array) field - an array with field description
	 *
	 * @return (string) output - a string with a html layout of the field
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function show_field_layout( $id, $name, $field ) {
		return '<input type="button"'
					. ( ! empty( $field['class_field'] ) ? ' class="' . esc_attr( $field['class_field'] ) . '"' : '' )
					. ' name="trx_effects_options_field_' . esc_attr( $name ) . '"'
					. ' value="' . esc_attr( ! empty( $field['caption'] ) ? $field['caption'] : $field['title'] ) . '"'
					. ' data-action="' . esc_attr( ! empty( $field['action'] ) ? $field['action'] : $field['std'] ) . '"'
					. ( ! empty( $field['callback'] ) ? ' data-callback="' . esc_attr( $field['callback'] ) . '"' : '' )
				. '>';
	}

}
