<?php
namespace TrxEffects\Core\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * An option field of the type 'checklist'
 *
 * Add a checklist (sortable group of checkboxes) to the options page
 *
 * @since 1.0.0
 */
class CustomizerFieldChecklist extends CustomizerField {

	/**
	 * Display an inner layout of the field.
	 *
	 * Display tags inside field's wrapper.
	 *
	 * @param (string) name - a name of the field
	 * @param (array) field - an array with field description
	 *
	 * @return (string) output - a string with a html layout of the field
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function show_field_layout( $id, $name, $field ) {
		$field['options'] = apply_filters( 'trx_effects_filter/options_get_list_choises', $field['options'], $name );
		$output = '<div class="trx_effects_options_item_choises' . ( ! empty( $field['sortable'] ) ? ' trx_effects_options_sortable' : '' ) . '">';
		// Convert string value to the array
		if ( ! empty( $field['val'] ) && ! is_array( $field['val'] ) ) {
			parse_str( str_replace( '|', '&', $field['val'] ), $field['val'] );
		}
		// Sort options by values order
		if ( ! empty( $field['sortable'] ) && is_array( $field['val'] ) ) {
			$field['options'] = trx_effects_array_merge( $field['val'], $field['options'] );
		}
		foreach ( $field['options'] as $k => $v ) {
			$output .= '<label class="trx_effects_options_item_label' 
							. ( ! empty( $field['sortable'] ) ? ' trx_effects_options_item_sortable' : '' )
						. '">'
							. '<input type="checkbox"'
								. ( ! empty( $field['class_field'] ) ? ' class="' . esc_attr( $field['class_field'] ) . '"' : '' )
								. ' name="trx_effects_options_field_' . esc_attr( $name ) . '[' . $k . ']"'
								. ' value="1"'
								. ' data-name="' . $k . '"'
								. ( isset( $field['val'][ $k ] ) && (int)$field['val'][ $k ] == 1 ? ' checked="checked"' : '' )
							. ' />'
							. ( substr( $v, 0, 4 ) == 'http' ? '<img src="' . esc_url( $v ) . '">' : esc_html( $v ) )
					. '</label>';
		}
		$output .= '<input type="hidden" name="trx_effects_options_field_' . esc_attr( $name ) . '"' . ' value="' . $this->prepare_field_value( $field ) . '" />'
				. '</div>';
		return $output;
	}

}
