<?php
namespace TrxEffects\Core\Options;

use TrxEffects\Plugin;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * An option field of the type 'map'
 *
 * Add a map to the options page
 *
 * @since 1.0.0
 */
class CustomizerFieldMap extends CustomizerField {

	/**
	 * Display an inner layout of the field.
	 *
	 * Display tags inside field's wrapper.
	 *
	 * @param (string) name - a name of the field
	 * @param (array) field - an array with field description
	 *
	 * @return (string) output - a string with a html layout of the field
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function show_field_layout( $id, $name, $field ) {
		$output = '<input type="hidden" id="trx_effects_options_field_' . esc_attr( $id ) . '"'
						. ' name="trx_effects_options_field_' . esc_attr( $name ) . '"'
						. ' value="' . esc_attr( $field['val'] ) . '"'
					. ' />';
		$map_type = '';
		if ( $field['type'] == 'googlemap' ) {
			$map_type = 'googlemap';
			trx_effects_enqueue_googlemap();
		} else if ( $field['type'] == 'yandexmap' ) {
			$map_type = 'yandexmap';
			trx_effects_enqueue_yandexmap();
		} else if ( $field['type'] == 'osmap' ) {
			$map_type = 'osmap';
			trx_effects_enqueue_osmap();
		} else if ( $field['type'] == 'map' ) {
			if ( $this->check_option( 'api_google_load' ) && trx_effects_is_on( $this->get_option( 'api_google_load' ) ) && $this->get_option( 'api_google' ) != '' ) {
				$map_type = 'googlemap';
				trx_effects_enqueue_googlemap();
			} else if ( $this->check_option( 'api_yandex_load' ) && trx_effects_is_on( $this->get_option( 'api_yandex_load' ) ) ) {
				$map_type = 'yandexmap';
				trx_effects_enqueue_yandexmap();
			} else if ( $this->check_option( 'api_openstreet_load' ) && trx_effects_is_on( $this->get_option( 'api_openstreet_load' ) ) ) {
				$map_type = 'osmap';
				trx_effects_enqueue_osmap();
			}
		}
		$output .= '<div id="trx_effects_options_field_' . esc_attr( $name ) . '_map"'
						. ' class="trx_effects_options_map sc_' . esc_attr( $map_type )
							. ( ! empty( $field['class_field'] ) ? ' ' . esc_attr( $field['class_field'] ) : '' ) 
							. '"'
						. ' data-coords="' . esc_attr( $field['val'] ) . '"'
						. ' data-editable="1"'
						. ' style="height:' . esc_attr( empty( $field['height'] ) ? '200px' : Plugin::instance()->html->prepare_css_value( $field['height'] ) ) . '"'
					. '>'
					. '</div>'
					. '<div class="trx_effects_options_map_search">'
						. '<input type="text" class="trx_effects_options_map_search_text" value="" />'
						. '<input type="button" class="trx_effects_options_map_search_button"'
							. ' value="' . esc_attr__( 'Find by address', 'trx-effects' ) . '" />'
					. '</div>';
		return $output;
	}

}
