<?php
namespace TrxEffects\Core\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * An option field of the type 'range'
 *
 * Add a range selector to the options page
 *
 * @since 1.0.0
 */
class CustomizerFieldRange extends CustomizerField {

	/**
	 * Display an inner layout of the field.
	 *
	 * Display tags inside field's wrapper.
	 *
	 * @param (string) name - a name of the field
	 * @param (array) field - an array with field description
	 *
	 * @return (string) output - a string with a html layout of the field
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function show_field_layout( $id, $name, $field ) {

		$is_range   = 'range' == $field['type'];
		$show_value = ! isset( $field['show_value'] ) || $field['show_value'];
		$field_min  = ! empty( $field['min'] ) ? $field['min'] : 0;
		$field_max  = ! empty( $field['max'] ) ? $field['max'] : 100;
		$field_step = ! empty( $field['step'] ) ? $field['step'] : 1;
		$field_val  = ! empty( $field['val'] )
						? ( $field['val'] . ( $is_range && strpos( $field['val'], ',' ) === false ? ',' . $field_max : '' ) )
						: ( $is_range ? $field_min . ',' . $field_max : $field_min );

		$output = '<input type="' . ( ! $show_value ? 'hidden' : 'text' ) . '" id="trx_effects_options_field_' . esc_attr( $name ) . '"'
						. ' name="trx_effects_options_field_' . esc_attr( $name ) . '"'
						. ' value="' . esc_attr( $field['val'] ) . '"'
						. ( $show_value ? ' class="trx_effects_range_slider_value"' : '' )
						. ' />'
					. '<div id="trx_effects_options_field_' . esc_attr( $name ) . '_slider"'
						. ' class="trx_effects_range_slider"'
						. ' data-range="' . esc_attr( $is_range ? 'true' : 'min' ) . '"'
						. ' data-min="' . esc_attr( $field_min ) . '"'
						. ' data-max="' . esc_attr( $field_max ) . '"'
						. ' data-step="' . esc_attr( $field_step ) . '"'
					. '>'
						. '<span class="trx_effects_range_slider_label trx_effects_range_slider_label_min">'
							. esc_html( $field_min )
						. '</span>'
						. '<span class="trx_effects_range_slider_label trx_effects_range_slider_label_max">'
							. esc_html( $field_max )
						. '</span>';
		$values = explode( ',', $field_val );
		for ( $i = 0; $i < count( $values ); $i++ ) {
			$output .= '<span class="trx_effects_range_slider_label trx_effects_range_slider_label_cur">'
							. esc_html( $values[ $i ] )
						. '</span>';
		}
		$output .= '</div>';
		return $output;
	}

}
