<?php
namespace TrxEffects\Core\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * An option field of the type 'select'
 *
 * Add a select to the options page
 *
 * @since 1.0.0
 */
class CustomizerFieldSelect extends CustomizerField {

	/**
	 * Display an inner layout of the field.
	 *
	 * Display tags inside field's wrapper.
	 *
	 * @param (string) name - a name of the field
	 * @param (array) field - an array with field description
	 *
	 * @return (string) output - a string with a html layout of the field
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function show_field_layout( $id, $name, $field ) {
		$field['options'] = apply_filters( 'trx_effects_filter/options_get_list_choises', $field['options'], $name );
		$output = '<select'
						. ( ! empty( $field['class_field'] ) ? ' class="' . esc_attr( $field['class_field'] ) . '"' : '' )
						. ' name="trx_effects_options_field_' . esc_attr( $name ) . ( ! empty( $field['multiple'] ) ? '[]' : '' ) . '"'
						. ( ! empty( $field['multiple'] ) ? ' multiple="multiple"' : ' size="1"' )
						. ( ! empty( $field['readonly'] ) ? ' readonly="readonly"' : '' )
					. '>';
		foreach ( $field['options'] as $k => $v ) {
			$output .= '<option value="' . esc_attr( $k ) . '"' . ( in_array( $k, (array)$field['val'] ) ? ' selected="selected"' : '' )
								. ' class="' . esc_attr( $k ) . '">'
							. esc_html( $v )
						. '</option>';
		}
		$output .= '</select>';
		return $output;
	}

}
