<?php
namespace TrxEffects\Core\Options;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * An option field of the type 'text'
 *
 * Add a text to the options page
 *
 * @since 1.0.0
 */
class CustomizerFieldText extends CustomizerField {

	/**
	 * Display an inner layout of the field.
	 *
	 * Display tags inside field's wrapper.
	 *
	 * @param (string) name - a name of the field
	 * @param (array) field - an array with field description
	 *
	 * @return (string) output - a string with a html layout of the field
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function show_field_layout( $id, $name, $field ) {
		$output = '<input type="text"'
					. ( ! empty( $field['class_field'] ) ? ' class="' . esc_attr( $field['class_field'] ) . '"' : '')
					. ' name="trx_effects_options_field_' . esc_attr( $name ) . '"'
					. ' value="' . esc_attr( $field['val'] ) . '"'
					. ( ! empty( $field['readonly'] ) ? ' readonly="readonly"' : '' )
					. ( ! empty( $field['placeholder'] ) ? ' placeholder="' . esc_attr( $field['placeholder'] ) . '"' : '' );
		if ( isset( $field['data'] ) && is_array( $field['data'] ) ) {
			foreach( $field['data'] as $k => $v ) {
				$output .= ' data-' . esc_attr( $k ) . '="' . esc_attr( $v ) . '"';
			}
		}
		$output .= ' />';
		return $output;
	}

}
